@@ -38,8 +38,6 @@
   "The channel you currently have joined.")
 (defvar riece-current-channels nil
   "The channels you have currently joined.")
-(defvar riece-last-channel nil
-  "The channel you had joined the last time.")
 
 (defvar riece-save-variables-are-dirty nil
   "Non nil if the variables in `riece-saved-forms' are changed.")
@@ -132,7 +130,7 @@ Local to the channel buffers.")
   "Name of channel message buffer.")
 (defvar riece-channel-buffer-format "*Channel:%s*"
   "Format of channel message buffer.")
-(defvar riece-channel-list-buffer " *Channels*"
+(defvar riece-channel-list-buffer "*Channels*"
   "Name of channel list buffer.")
 (defvar riece-user-list-buffer " *Users*"
   "Name of user list buffer.")
