@@ -100,7 +100,12 @@ way is to put Riece variables on .emacs or file loaded from there."
   :type '(repeat (file :tag "Initialization File"))
   :group 'riece-options)
 
-(defcustom riece-addons '(riece-highlight riece-ctcp)
+(defcustom riece-addons '(riece-highlight
+			  riece-ctcp
+			  riece-guess
+			  riece-unread
+			  riece-history
+			  riece-url)
   "Add-ons insinuated into Riece."
   :type '(repeat symbol)
   :group 'riece-options)
@@ -233,11 +238,6 @@ way is to put Riece variables on .emacs or file loaded from there."
   :type 'boolean
   :group 'riece-options)
 
-(defcustom riece-connection-timeout 60
-  "Default timeout interval."
-  :type 'integer
-  :group 'riece-server)
-  
 (defcustom riece-buffer-dispose-function #'bury-buffer
   "Function called after the buffer was disposed."
   :type 'function
